@@ -1,12 +1,10 @@
-package Algorithm::CheckDigits::M97_002;
+package Algorithm::CheckDigits::M10_002;
 
 use 5.006;
 use strict;
 use warnings;
 use integer;
 
-use Math::BigInt;
-
 require Exporter;
 
 our @ISA = qw(Exporter Algorithm::CheckDigits);
@@ -26,15 +24,6 @@ our @EXPORT_OK = ( 'new', @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = ();
 
-my %subst = (
-	A => 10, B => 11, C => 12, D => 13, E => 14,
-	F => 15, G => 16, H => 17, I => 18, J => 19,
-	K => 20, L => 21, M => 22, N => 23, O => 24,
-	P => 25, Q => 26, R => 27, S => 28, T => 29,
-	U => 30, V => 31, W => 32, X => 33, Y => 34,
-	Z => 35,
-);
-
 sub new {
 	my $proto = shift;
 	my $type  = shift;
@@ -46,32 +35,32 @@ sub new {
 
 sub is_valid {
 	my ($self,$number) = @_;
-	if ($number =~ /^[A-Z]{2}(\d\d)\s?[\d ]{0,37}$/i) {
-		return $1 eq $self->_compute_checkdigit($number);
+	if ($number =~ /^([0-9 ]*)([0-9])$/) {
+		return $2 == $self->_compute_checkdigit($1);
 	}
 	return ''
 } # is_valid()
 
 sub complete {
 	my ($self,$number) = @_;
-	if ($number =~ /^([A-Z]{2})(00)(\s?[\d ]{0,37})$/i) {
-		return $1 . $self->_compute_checkdigit($number) . $3;
+	if ($number =~ /^[0-9 ]*$/) {
+		return  $number . $self->_compute_checkdigit($number);
 	}
 	return '';
 } # complete()
 
 sub basenumber {
 	my ($self,$number) = @_;
-	if ($number =~ /^([A-Z]{2})(\d\d)(\s?[\d ]{0,37})$/i) {
-		return $1.'00'.$3 if ($2 eq $self->_compute_checkdigit($number));
+	if ($number =~ /^([0-9 ]*)([0-9])$/) {
+		return $1 if ($2 == $self->_compute_checkdigit($1));
 	}
 	return '';
 } # basenumber()
 
 sub checkdigit {
 	my ($self,$number) = @_;
-	if ($number =~ /^([A-Z]{2})(\d\d)(\s?[\d ]{0,37})$/i) {
-		return $2 if ($2 eq $self->_compute_checkdigit($number));
+	if ($number =~ /^([0-9 ]*)([0-9])$/) {
+		return $2 if ($2 == $self->_compute_checkdigit($1));
 	}
 	return '';
 } # checkdigit()
@@ -79,13 +68,21 @@ sub checkdigit {
 sub _compute_checkdigit {
 	my $self   = shift;
 	my $number = shift;
-
 	$number =~ s/\s//g;
-
-	if ($number =~ /^([A-Z])([A-Z])..([ \d]{0,37})$/i) {
-		my $bignum = Math::BigInt->new($3.$subst{$1}.$subst{$2}.'00');
-		my $mod    = $bignum % 97;
-		return sprintf("%2.2d",(98 - $mod));
+	if ($number =~ /^([0-9]*)$/) {
+		my @digits = split(//,$number);
+		my $even = 1;
+		my $sum  = 0;
+		for (my $i = $#digits; $i >= 0; $i--) {
+			if ($even) {
+				my $tmp = 2 * $digits[$i];
+				$sum += $tmp / 10 + $tmp % 10;
+			} else {
+				$sum += $digits[$i];
+			}
+			$even = not $even;
+		}
+		return (10 - $sum % 10) % 10;
 	}
 	return -1;
 } # _compute_checkdigit()
@@ -97,27 +94,27 @@ __END__
 
 =head1 NAME
 
-CheckDigits::M97_002 - compute check digits for International Bank
-Account Number (IBAN)
+CheckDigits::M10_002 - compute check digits for CINS (US), SIREN (FR),
+SIRET (FR)
 
 =head1 SYNOPSIS
 
   use CheckDigits;
 
-  $iban = CheckDigits('iban');
+  $siret = CheckDigits('siret');
 
-  if ($iban->is_valid('DE88 2008 0000 09703 7570 0')) {
+  if ($siret->is_valid('73282932000074')) {
 	# do something
   }
 
-  $cn = $iban->complete('DE00 2008 0000 09703 7570 0');
-  # $cn = 'DE88 2008 0000 09703 7570 0'
+  $cn = $siret->complete('7328293200007');
+  # $cn = '73282932000074'
 
-  $cd = $iban->checkdigit('DE88 2008 0000 09703 7570 0');
-  # $cd = '88'
+  $cd = $siret->checkdigit('73282932000074');
+  # $cd = '4'
 
-  $bn = $iban->basenumber('DE88 2008 0000 09703 7570 0');
-  # $bn = 'DE00 2008 0000 09703 7570 0'
+  $bn = $siret->basenumber('73282932000074');
+  # $bn = '7328293200007'
   
 =head1 DESCRIPTION
 
@@ -125,24 +122,22 @@ Account Number (IBAN)
 
 =over 4
 
-=item 0
-
-The IBAN number must be prepared. The first two letters and the
-checksum will be moved to the right end. The letters are substituted
-according to the substitute table and the checksum is set to '00'.
-
 =item 1
 
-The whole number (without checksum) is taken modulo 97.
+Beginning right all numbers are weighted alternatively 1 and 2.
 
 =item 2
 
-The checksum is difference between 98 and the sum of step 2.
+The total of the digits of all products is computed.
 
 =item 3
 
-If the checksum is smaller then 10, a leading zero will be
-supplemented.
+The sum of step 3 ist taken modulo 10.
+
+=item 4
+
+The check digit is the difference between 10 and the number from step
+3 taken modulo 10.
 
 =back
 
@@ -174,7 +169,7 @@ Return '' otherwise.
 
 =item checkdigit($number)
 
-Returns the checkdigits of C<$number> if C<$number> has a valid check
+Returns the checkdigit of C<$number> if C<$number> has a valid check
 digit.
 
 Return '' otherwise.
@@ -194,5 +189,6 @@ Mathias Weidner, E<lt>mathias@weidner.in-bad-schmiedeberg.deE<gt>
 L<perl>,
 L<CheckDigits>,
 F<www.pruefziffernberechnung.de>.
+F<www.dsi.cnrs.fr/bureau_qualite/admindonnees/documents/siren.pdf>
 
 =cut
